@@ -686,8 +686,8 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         Returns:
             google.cloud.secretmanager_v1.types.Secret:
-                A [Secret][google.cloud.secretmanager.v1.Secret] is a logical secret whose value and versions can
-                   be accessed.
+                A [Secret][google.cloud.secretmanager.v1.Secret] is a logical secret whose
+                   value and versions can be accessed.
 
                    A [Secret][google.cloud.secretmanager.v1.Secret] is
                    made up of zero or more
@@ -917,8 +917,8 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         Returns:
             google.cloud.secretmanager_v1.types.Secret:
-                A [Secret][google.cloud.secretmanager.v1.Secret] is a logical secret whose value and versions can
-                   be accessed.
+                A [Secret][google.cloud.secretmanager.v1.Secret] is a logical secret whose
+                   value and versions can be accessed.
 
                    A [Secret][google.cloud.secretmanager.v1.Secret] is
                    made up of zero or more
@@ -1032,8 +1032,8 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         Returns:
             google.cloud.secretmanager_v1.types.Secret:
-                A [Secret][google.cloud.secretmanager.v1.Secret] is a logical secret whose value and versions can
-                   be accessed.
+                A [Secret][google.cloud.secretmanager.v1.Secret] is a logical secret whose
+                   value and versions can be accessed.
 
                    A [Secret][google.cloud.secretmanager.v1.Secret] is
                    made up of zero or more
