@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,8 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
 
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.secretmanager_v1beta1.types import resources
@@ -62,11 +62,18 @@ class ListSecretsRequest(proto.Message):
             [ListSecretsResponse.next_page_token][google.cloud.secrets.v1beta1.ListSecretsResponse.next_page_token].
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListSecretsResponse(proto.Message):
@@ -74,7 +81,7 @@ class ListSecretsResponse(proto.Message):
     [SecretManagerService.ListSecrets][google.cloud.secrets.v1beta1.SecretManagerService.ListSecrets].
 
     Attributes:
-        secrets (Sequence[google.cloud.secretmanager_v1beta1.types.Secret]):
+        secrets (MutableSequence[google.cloud.secretmanager_v1beta1.types.Secret]):
             The list of [Secrets][google.cloud.secrets.v1beta1.Secret]
             sorted in reverse by create_time (newest first).
         next_page_token (str):
@@ -91,15 +98,19 @@ class ListSecretsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    secrets = proto.RepeatedField(
+    secrets: MutableSequence[resources.Secret] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=resources.Secret,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
-
-    total_size = proto.Field(proto.INT32, number=3)
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    total_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
 
 
 class CreateSecretRequest(proto.Message):
@@ -123,11 +134,15 @@ class CreateSecretRequest(proto.Message):
             with initial field values.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    secret_id = proto.Field(proto.STRING, number=2)
-
-    secret = proto.Field(
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    secret_id: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    secret: resources.Secret = proto.Field(
         proto.MESSAGE,
         number=3,
         message=resources.Secret,
@@ -150,9 +165,11 @@ class AddSecretVersionRequest(proto.Message):
             [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion].
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    payload = proto.Field(
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    payload: resources.SecretPayload = proto.Field(
         proto.MESSAGE,
         number=2,
         message=resources.SecretPayload,
@@ -170,7 +187,10 @@ class GetSecretRequest(proto.Message):
             ``projects/*/secrets/*``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListSecretVersionsRequest(proto.Message):
@@ -195,11 +215,18 @@ class ListSecretVersionsRequest(proto.Message):
             ListSecretVersionsResponse.next_page_token][].
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListSecretVersionsResponse(proto.Message):
@@ -207,7 +234,7 @@ class ListSecretVersionsResponse(proto.Message):
     [SecretManagerService.ListSecretVersions][google.cloud.secrets.v1beta1.SecretManagerService.ListSecretVersions].
 
     Attributes:
-        versions (Sequence[google.cloud.secretmanager_v1beta1.types.SecretVersion]):
+        versions (MutableSequence[google.cloud.secretmanager_v1beta1.types.SecretVersion]):
             The list of
             [SecretVersions][google.cloud.secrets.v1beta1.SecretVersion]
             sorted in reverse by create_time (newest first).
@@ -225,15 +252,19 @@ class ListSecretVersionsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    versions = proto.RepeatedField(
+    versions: MutableSequence[resources.SecretVersion] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=resources.SecretVersion,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
-
-    total_size = proto.Field(proto.INT32, number=3)
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    total_size: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
 
 
 class GetSecretVersionRequest(proto.Message):
@@ -250,7 +281,10 @@ class GetSecretVersionRequest(proto.Message):
             [SecretVersion][google.cloud.secrets.v1beta1.SecretVersion].
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateSecretRequest(proto.Message):
@@ -265,16 +299,15 @@ class UpdateSecretRequest(proto.Message):
             Required. Specifies the fields to be updated.
     """
 
-    secret = proto.Field(
+    secret: resources.Secret = proto.Field(
         proto.MESSAGE,
         number=1,
         message=resources.Secret,
     )
-
-    update_mask = proto.Field(
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
         proto.MESSAGE,
         number=2,
-        message=field_mask.FieldMask,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -289,7 +322,10 @@ class AccessSecretVersionRequest(proto.Message):
             in the format ``projects/*/secrets/*/versions/*``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class AccessSecretVersionResponse(proto.Message):
@@ -305,9 +341,11 @@ class AccessSecretVersionResponse(proto.Message):
             Secret payload
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    payload = proto.Field(
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    payload: resources.SecretPayload = proto.Field(
         proto.MESSAGE,
         number=2,
         message=resources.SecretPayload,
@@ -325,7 +363,10 @@ class DeleteSecretRequest(proto.Message):
             the format ``projects/*/secrets/*``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DisableSecretVersionRequest(proto.Message):
@@ -340,7 +381,10 @@ class DisableSecretVersionRequest(proto.Message):
             ``projects/*/secrets/*/versions/*``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class EnableSecretVersionRequest(proto.Message):
@@ -354,7 +398,10 @@ class EnableSecretVersionRequest(proto.Message):
             to enable in the format ``projects/*/secrets/*/versions/*``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DestroySecretVersionRequest(proto.Message):
@@ -369,7 +416,10 @@ class DestroySecretVersionRequest(proto.Message):
             ``projects/*/secrets/*/versions/*``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
